@@ -417,7 +417,7 @@ class PM(Module):
     ) -> bytes:
         """
         Returns the release id generated by releasing a package on the current registry.
-        Requires ``web3.PM`` to have a registry set. Requires ``web3.eth.defaultAccount``
+        Requires ``web3.PM`` to have a registry set. Requires ``web3.eth.default_account``
         to be the registry owner.
 
         * Parameters:
